Moodle API Client
=================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   pages/api
   pages/moodle
   pages/exceptions


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
